gh_letters: Get compact letter display from Games-Howell results

View source: R/games.howell.R

gh_lettersR Documentation

Get compact letter display from Games-Howell results

Description

Converts Games-Howell test results into compact letter display using multcompView. Groups sharing a letter are not significantly different.

Usage

gh_letters(x, alpha = 0.05)

Arguments

x

A games.howell object from games.howell()

alpha

Significance level (default: 0.05)

Value

A named vector with group names and their letter codes

Examples

# Convert dose to factor
ToothGrowth$dose <- as.factor(ToothGrowth$dose)
result <- games.howell(ToothGrowth$len, ToothGrowth$dose)
letters <- gh_letters(result)
print(letters)


visStatistics documentation built on May 13, 2026, 1:08 a.m.