| gh_letters | R Documentation |
Converts Games-Howell test results into compact letter display using multcompView. Groups sharing a letter are not significantly different.
gh_letters(x, alpha = 0.05)
x |
A games.howell object from |
alpha |
Significance level (default: 0.05) |
A named vector with group names and their letter codes
# Convert dose to factor
ToothGrowth$dose <- as.factor(ToothGrowth$dose)
result <- games.howell(ToothGrowth$len, ToothGrowth$dose)
letters <- gh_letters(result)
print(letters)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.