View source: R/visstat_methods.R
| print.visstat | R Documentation |
Displays a brief summary of the statistical test results and, if available, assumption tests and post hoc comparisons.
## S3 method for class 'visstat'
print(x, ...)
x |
An object of class |
... |
Currently unused. Included for S3 method compatibility. |
Quick overview of the statistical analysis results.
The object x, invisibly.
summary.visstat,
plot.visstat, visstat
anova <- visstat(npk$block, npk$yield)
print(anova)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.