Learn R Programming

visStatistics (version 0.3.0)

print.visstat: Print method for visstat objects

Description

Displays a brief summary of the statistical test results and, if available, assumption tests and post hoc comparisons.

Usage

# S3 method for visstat
print(x, ...)

Value

The object x, invisibly.

Arguments

x

An object of class "visstat", returned by visstat().

...

Currently unused. Included for S3 method compatibility.

Details

Quick overview of the statistical analysis results.

See Also

summary.visstat, plot.visstat, visstat

Examples

Run this code
anova <- visstat(npk$block, npk$yield)
print(anova)

Run the code above in your browser using DataLab