powered by
Displays a brief summary of the statistical test results and, if available, assumption tests and post hoc comparisons.
# S3 method for visstat print(x, ...)
The object x, invisibly.
x
An object of class "visstat", returned by visstat().
"visstat"
visstat()
Currently unused. Included for S3 method compatibility.
Quick overview of the statistical analysis results.
summary.visstat, plot.visstat, visstat
summary.visstat
plot.visstat
visstat
anova <- visstat(npk$block, npk$yield) print(anova)
Run the code above in your browser using DataLab