qq_lm_envelope: Simulated Q-Q envelopes for linear model residuals
Description
Computes pointwise and simultaneous Q-Q envelopes for internally
studentised residuals from an unweighted lm or aov object by
repeatedly simulating responses from the fitted normal-error model and
refitting the model. The simultaneous envelope follows the Monte Carlo
tolerance-band idea of Schuetzenmeister et al. (2012,
doi:10.1080/03610918.2011.582560).
A list of class qq_lm_envelope with the observed sorted
residuals, theoretical quantiles, pointwise bounds, simultaneous bounds,
the simulated sorted residual matrix, and the achieved simultaneous
coverage.