View source: R/visstat_methods.R
| summary.visstat | R Documentation |
Displays the full statistical test results and, if available, assumption tests and post hoc comparisons.
## S3 method for class 'visstat'
summary(object, ...)
object |
An object of class |
... |
Currently unused. Included for S3 method compatibility. |
This method provides a full textual report of the statistical
test results returned by visstat(), and prints the contents of
posthoc_summary if present.
The object object, invisibly.
print.visstat, visstat
anova <- visstat(npk$block, npk$yield)
summary(anova)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.