Learn R Programming

visStatistics (version 0.3.0)

summary.visstat: Summary method for visstat objects

Description

Displays the full statistical test results and, if available, assumption tests and post hoc comparisons.

Usage

# S3 method for visstat
summary(object, ...)

Value

The object object, invisibly.

Arguments

object

An object of class "visstat", returned by visstat().

...

Currently unused. Included for S3 method compatibility.

Details

This method provides a full textual report of the statistical test results returned by visstat(), and prints the contents of posthoc_summary if present.

See Also

print.visstat, visstat

Examples

Run this code
anova <- visstat(npk$block, npk$yield)
summary(anova)

Run the code above in your browser using DataLab